# Документирующий комментарий не содержит секцию "Описание" для экспортной процедуры (функции)

**Секция "Описание"** содержит описание назначения процедуры (функции),
достаточное для понимания сценариев ее использования без просмотра ее исходного кода.
Также может содержать краткое описание принципов работы и перекрестные ссылки на связанные процедуры и функции.
Может быть единственной секцией для процедур без параметров.

Описание не должно совпадать с именем процедуры (функции).
Для процедур и функций секция должна начинаться с глагола. Для функций это, как правило:
«Возвращает…». В тех случаях, когда возвращаемый результат является не основным в работе функции, – 
то с основного действия, например: «Проверяет…», «Сравнивает…», «Вычисляет…» и т.п.
Не рекомендуется начинать описание с избыточных слов «Процедура...», «Функция...»,
а также с имени самой процедуры (функции), от удаления которых смысл не меняется.

## Неправильно

```bsl

#Область ПрограммныйИнтерфейс

// Параметры:
//   ИменаРолей - Строка - имена ролей, доступность которых проверяется, разделенные запятыми.
//
// Возвращаемое значение:
//   Булево - Истина, если хотя бы одна из переданных ролей доступна текущему пользователю,
//   либо у него есть административные права.
//
// Пример:
// Если РолиДоступны("ИспользованиеРассылокОтчетов,ОтправкаПоПочте") Тогда ...
//
Функция РолиДоступны(ИменаРолей) Экспорт
    // код
КонецФункции

#КонецОбласти

```

## Правильно

```bsl

#Область ПрограммныйИнтерфейс

// Определяет доступность ролей ИменаРолей текущему пользователю,
// а также доступность административных прав.
//
// Параметры:
//   ИменаРолей - Строка - имена ролей, доступность которых проверяется, разделенные запятыми.
//
// Возвращаемое значение:
//   Булево - Истина, если хотя бы одна из переданных ролей доступна текущему пользователю,
//   либо у него есть административные права.
//
// Пример:
// Если РолиДоступны("ИспользованиеРассылокОтчетов,ОтправкаПоПочте") Тогда ...
//
Функция РолиДоступны(ИменаРолей) Экспорт
    // код
КонецФункции

#КонецОбласти

```

## См.

- [Описание процедур и функций](https://its.1c.ru/db/v8std#content:453:hdoc:2)
