# Конструкция "Попытка...Исключение...КонецПопытки" не содержит кода в исключении

Недопустимо перехватывать любые исключения, бесследно для системного
администратора.

Как правило, подобная конструкция скрывает реальную проблему, которую
впоследствии невозможно диагностировать.

## Неправильно

```bsl
Попытка  
// код, приводящий к вызову исключения  
....  
Исключение // перехват любых исключений  
КонецПопытки;
```

## Правильно

```bsl
Попытка  
// код, приводящий к вызову исключения  
....  
Исключение  
// Пояснение причин перехвата всех исключений "незаметно" от пользователя.  
// ....  
// И запись события в журнал регистрации для системного администратора.  
ЗаписьЖурналаРегистрации(НСтр("ru = 'Выполнение операции'"),  
    УровеньЖурналаРегистрации.Ошибка,,,  
    ПодробноеПредставлениеОшибки(ИнформацияОбОшибке()));  
КонецПопытки;
```

## Подавление проверки

В случаях когда отсутствующий код в блоке исключения является особенностью проектирования, есть возможность
подавить срабатывание проверки на конкретном выражении и оставить поясняющий комментарий:
```bsl
// @skip-check empty-except-statement - не отлавливаем исключение потому что...
Попытка
  ... 
Исключение
КонецПопытки;
```

## См.

- [Перехват исключений в коде](https://its.1c.ru/db/v8std#content:499:hdoc:2)