# Отсутствует комментарий к экспортной процедуре (функции)

Описание **процедур и функций** рекомендуется выполнять в виде комментария к ним.
Необходимость комментирования отдельных участков кода процедур и функций должна определяться разработчиком
исходя из сложности и нестандартности конкретного участка кода.

Обязательного комментирования требуют процедуры и функции входящие в **программный интерфейс модулей** -
такие процедуры и функции предназначены для использования в других функциональных подсистемах
(или в других приложениях), за которые могут отвечать другие разработчики,
поэтому они должны быть хорошо документированы.

## Неправильно

```bsl

#Область ПрограммныйИнтерфейс

Функция РолиДоступны(ИменаРолей) Экспорт
    // код
КонецФункции

#КонецОбласти

```

## Правильно

```bsl

#Область ПрограммныйИнтерфейс

// Определяет доступность ролей ИменаРолей текущему пользователю,
// а также доступность административных прав.
//
// Параметры:
//   ИменаРолей - Строка - имена ролей, доступность которых проверяется, разделенные запятыми.
//
// Возвращаемое значение:
//   Булево - Истина, если хотя бы одна из переданных ролей доступна текущему пользователю,
//   либо у него есть административные права.
//
// Пример:
// Если РолиДоступны("ИспользованиеРассылокОтчетов,ОтправкаПоПочте") Тогда ...
//
Функция РолиДоступны(ИменаРолей) Экспорт
    // код
КонецФункции

#КонецОбласти

```

## См.

- [Описание процедур и функций](https://its.1c.ru/db/v8std#content:453:hdoc:2)
